@@ -11,14 +11,16 @@ returned from `Request.execute()` or expects `file_handle` would
 implement pathlib.Path.write_bytes()
 
 """
+import json
 
-from yaml import serialize
 import ifirma.config as Config
+from ifirma.invoice import Invoice
 from ifirma.request import Request
 
 
 def create_invoice(invoice):
     from ifirma.request import InvoiceResponse
+
     http = Config.get_http_module()
 
     data = _serialize(invoice)
@@ -47,9 +49,10 @@ def download_invoice(invoice_id, file_handle):
     resp.raise_for_status()
     file_handle.write_bytes(resp.content)
 
-def _serialize(invoice_or_string):
-    if isinstance(invoice_or_string, str):
-        return invoice_or_string
+
+def _serialize(invoice_kind):
+    if not isinstance(invoice_kind, Invoice):
+        return invoice_kind
 
     serializer = Config.get_serializer_module()
-    return serializer.make_invoice(invoice_or_string)
+    return serializer.make_invoice(invoice_kind)
